package com.example.haiwei_mom.ipc;

import android.annotation.SuppressLint;
import android.os.Bundle;
import android.view.View;

import androidx.databinding.DataBindingUtil;

import com.example.haiwei_mom.R;
import com.example.haiwei_mom.base.BaseActivity;
import com.example.haiwei_mom.base.MyRecultCall;
import com.example.haiwei_mom.base.MyResult;
import com.example.haiwei_mom.databinding.ActivityFeedingMaterialsBinding;
import com.example.haiwei_mom.ipc.data.MachinePlan;
import com.example.haiwei_mom.uitls.SharedPreferencesUtils;
import com.google.gson.reflect.TypeToken;
import com.lzy.okgo.OkGo;
import com.lzy.okgo.model.Response;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import okhttp3.RequestBody;

public class FeedingMaterialsActivity extends BaseActivity {
    private ActivityFeedingMaterialsBinding binding;
    private MachinePlan machinePlan;
    private String machineNo;
    private String from;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = DataBindingUtil.setContentView(this, R.layout.activity_feeding_materials);
        String title = getIntent().getStringExtra("title");
        binding.setTitle(title);
        from = getIntent().getStringExtra("from");
        machineNo = SharedPreferencesUtils.getstring("machineNo", null);
        binding.feedingCode.setText(machineNo);
        initRequest();
        selectMachineStationList();
        binding.feedingBarCode.setOnEditorActionListener((v, actionId, event) -> {
            feedingCodeSubmit(null);
            return true;
        });
    }

    // 获取计划
    private void initRequest() {
        Map map = new HashMap();
        map.put("MachineNo", machineNo);
        OkGo.<MyResult>post("http://" + SharedPreferencesUtils.getstring("machineIp", null) + "/api/plan/sel")
                .upRequestBody(RequestBody.create(JSON, gson.toJson(map)))
                .execute(new MyRecultCall(dialog, this) {
                    @SuppressLint("NotifyDataSetChanged")
                    @Override
                    public void onSuccess(Response<MyResult> response) {
                        super.onSuccess(response);
                        var body = response.body();
                        if (body.getCode() == 200) {

                            machinePlan = gson.fromJson(body.getDataJson(), MachinePlan.class);
                            binding.setMachineState(body.getMsg());
                            binding.setData(machinePlan);

                            return;
                        }
                        myToastUitls.show(body.getMsg());
                    }
                });
    }

    private void selectMachineStationList() {
        OkGo.<MyResult>post(url + "/wms/pda/selectMachineStationList")
                .params("machineId", SharedPreferencesUtils.getLong("machineId", 0L))

                .execute(new MyRecultCall(dialog, this) {
                    @Override
                    public void onSuccess(Response<MyResult> response) {
                        super.onSuccess(response);
                        var body = response.body();
                        if (body.getCode() == 200) {
                            List<String> list = gson.fromJson(body.getDataJson(), new TypeToken<List<String>>() {
                            }.getType());
                            binding.setList(list);
                            return;
                        }
                        myToastUitls.show(body.getMsg());
                    }
                });
    }

    @Override
    public void getScannerData(String data) {
        super.getScannerData(data);
        if (machinePlan == null) {
            return;
        }
        machinePlan.setFrom(from);
        // if (from.equals("4")){
        //     machinePlan.setWorkCode(data);
        // }else {
        machinePlan.setBarCode(data);
        // }
        machinePlan.setStationCode(binding.feedingSelectStation.getSelectedItem().toString());
        OkGo.<MyResult>post("http://" + SharedPreferencesUtils.getstring("machineIp", null) +
                        "/api/semi_product/scan")
                // .params("machineNo", machineNo)
                .upRequestBody(RequestBody.create(JSON, gson.toJson(machinePlan)))
                .execute(new MyRecultCall(dialog, this) {
                    @SuppressLint("NotifyDataSetChanged")
                    @Override
                    public void onSuccess(Response<MyResult> response) {
                        super.onSuccess(response);
                        var body = response.body();
                        if (body.getCode() == 200) {
                            machinePlan = gson.fromJson(body.getDataJson(), MachinePlan.class);
                            binding.setData(machinePlan);
                            binding.feedingBarCode.setText(null);
                            // Toast.makeText(FeedingMaterialsActivity.this, body.getMsg(), Toast.LENGTH_SHORT).show();
                            // return;
                        }
                        myToastUitls.show(body.getMsg());
                    }
                });
    }

    public void feedingCodeSubmit(View view) {

        String data = binding.feedingBarCode.getText().toString();
        if (data.isEmpty()) return;
        getScannerData(data);
    }
}